==> react-native-ui-view-0.1.2.tgz: package/esm/components/Cell/cell.js <==
import React, { isValidElement } from 'react';
import { View, StyleSheet, Text } from 'react-native';
import { Theme } from '../../components/Styles/theme';
import Icon from '../Icon';
import Touchable from '../Touchable';
const Cell = props => {
    const { title, label, border = true, centerRightText = true, rightContent, isLink = false, rightIconName = 'right', rightIconSize = 24, rightIconColor = Theme.colorTextGray, style, onPress, renderLeftIcon, } = props;
    return (React.createElement(Touchable, { style: [styles.container, border && styles.border, style], underlayColor: Theme.fillBody, onPress: onPress },
        React.createElement(React.Fragment, null,
            React.createElement(View, { style: styles.left },
                React.createElement(View, { style: styles.titleWrap },
                    renderLeftIcon ? React.createElement(View, { style: styles.iconWrap }, renderLeftIcon()) : null,
                    React.createElement(Text, { style: styles.titleText }, title)),
                !!label && (React.createElement(View, { style: styles.titleLabelWrap },
                    React.createElement(Text, { numberOfLines: 1, style: styles.titleLabel }, label)))),
            React.createElement(View, { style: [styles.right, { alignSelf: centerRightText ? 'center' : 'flex-start' }] },
                !!rightContent && (isValidElement(rightContent) ? rightContent : React.createElement(Text, null, rightContent)),
                isLink && React.createElement(Icon, { name: rightIconName, size: rightIconSize, color: rightIconColor })))));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 10,
    },
    border: {
        borderBottomColor: Theme.borderLightColor,
        borderBottomWidth: 0.5,
    },
    left: {
        flex: 1,
    },
    titleWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    iconWrap: {
        marginRight: 6,
    },
    titleText: {
        fontSize: 16,
        color: Theme.colorTextParagraph,
    },
    titleLabelWrap: {
        marginTop: 4,
    },
    titleLabel: {
        fontSize: 12,
        color: Theme.colorTextCaption,
    },
    right: {
        flexDirection: 'row',
        alignItems: 'center',
    },
});
export default Cell;

==> react-native-ui-view-0.1.7.tgz: package/esm/components/Cell/cell.js <==
import React, { isValidElement } from 'react';
import { View, StyleSheet, Text } from 'react-native';
import { Theme } from '../../components/Styles/theme';
import Icon from '../Icon';
import Touchable from '../Touchable';
const Cell = props => {
    const { title, titleStyle = {}, label, border = true, centerRightText = true, rightContent, isLink = false, rightIconName = 'right', rightIconSize = 24, rightIconColor = '#7f7f7f', style, onPress, renderLeftIcon, } = props;
    return (React.createElement(Touchable, { style: [styles.container, border && styles.border, style], underlayColor: Theme.fillBody, onPress: onPress },
        React.createElement(React.Fragment, null,
            React.createElement(View, { style: styles.left },
                React.createElement(View, { style: styles.titleWrap },
                    renderLeftIcon ? React.createElement(View, { style: styles.iconWrap }, renderLeftIcon()) : null,
                    React.createElement(Text, { style: [styles.titleText, titleStyle] }, title)),
                !!label && (React.createElement(View, { style: styles.titleLabelWrap },
                    React.createElement(Text, { numberOfLines: 1, style: styles.titleLabel }, label)))),
            React.createElement(View, { style: [styles.right, { alignSelf: centerRightText ? 'center' : 'flex-start' }] },
                !!rightContent && (isValidElement(rightContent) ? rightContent : React.createElement(Text, null, rightContent)),
                isLink && React.createElement(Icon, { name: rightIconName, size: rightIconSize, color: rightIconColor })))));
};
const styles = StyleSheet.create({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        paddingVertical: 12,
        paddingHorizontal: 10,
    },
    border: {
        borderBottomColor: Theme.borderLightColor,
        borderBottomWidth: 0.5,
    },
    left: {
        flex: 1,
    },
    titleWrap: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    iconWrap: {
        marginRight: 6,
    },
    titleText: {
        fontSize: 16,
        color: Theme.colorTextParagraph,
    },
    titleLabelWrap: {
        marginTop: 4,
    },
    titleLabel: {
        fontSize: 12,
        color: Theme.colorTextCaption,
    },
    right: {
        flexDirection: 'row',
        alignItems: 'center',
    },
});
export default Cell;
